==> AshCrypt-2.0.8.tar.gz: AshCrypt-2.0.8/setup.py <==
from setuptools import setup , find_packages

with open('AshCrypt/README.md','r') as f:
    readme = f.read()

setup(
    name='AshCrypt',
    version='2.0.8',
    author='Ashref Gwader',
    author_email='AshrefGw@proton.me',
    python_requires='>=3.7',
    description="Comprehensive AES-256 Cryptography App & library equipped with files & text handling modules along with"
                " a database module to store encrypted content.",
    long_description_content_type='text/markdown',
    long_description=readme,
    url='https://github.com/AshGw/AES-256.git',
    packages=find_packages(exclude=['important', 'Docker-build','.github','Executables','demo']),
    package_data={
        'AshCrypt': ['**'],
    },
    exclude_package_data={
        '': ['.gitignore','LICENSE','README'],
    },
    install_requires=[
        'bcrypt==4.0.1',
        'cryptography==40.0.2',
        'qrcode==7.4.2',
        'ttkbootstrap==1.10.1',
    ],
    classifiers=[
        'Development Status :: 5 - Production/Stable',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
        'Programming Language :: Python :: 3.9',
        'Programming Language :: Python :: 3.10',
        'Programming Language :: Python :: 3.11',
    ],
    keywords=[
        'Cryptography application',
        'cryptography library'
        'AES-256',
    ],
)

==> AshCrypt-3.0.6.tar.gz: AshCrypt-3.0.6/setup.py <==
from setuptools import setup, find_packages

with open('AshCrypt/README.md', 'r') as f:
    readme = f.read()

setup(
    name='AshCrypt',
    version='3.0.6',
    author='Ashref Gwader',
    author_email='AshrefGw@proton.me',
    python_requires='>=3.7',
    description="Comprehensive AES-256 Cryptography App & library equipped with files & text handling modules along"
                " with a database module to store encrypted content.",
    long_description_content_type='text/markdown',
    long_description=readme,
    url='https://github.com/AshGw/AES-256.git',
    packages=find_packages(exclude=['important', 'Docker-build', '.github', 'Executables', 'demo']),
    package_data={
        'AshCrypt': ['**'],
    },
    exclude_package_data={
        '': ['.gitignore', 'LICENSE', 'README'],
    },
    install_requires=[
        'bcrypt==4.0.1',
        'cryptography==40.0.2',
        'qrcode==7.4.2',
        'ttkbootstrap==1.10.1',
    ],
    classifiers=[
        'Development Status :: 5 - Production/Stable',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
        'Programming Language :: Python :: 3.9',
        'Programming Language :: Python :: 3.10',
        'Programming Language :: Python :: 3.11',
    ],
    keywords=[
        'Cryptography application',
        'cryptography library'
        'AES-256',
    ],
)
